@@ -1,6 +1,7 @@
 matrix2raster <- function(z,x,y,layer,proj="+proj=longlat"){
 #   #inst.pkg('raster')
-  if(class(z) == 'array'){
+
+  if(!is.matrix(z)){
     cat('\nconverting array to RasterStack object')
     
     if(missing(layer)) layer <- 1:dim(z)[3]
